
##
## extract a cryst group from database and translate it to a pcp group
##
CrystGroupAsPcpGroupIT := function( dim, nr )
    local r, d, G, B, i, H, N, n, M, P;

    # extract info
    r := rec( dim := dim, nr := nr, action := OnRight );
    d := SpaceGroupDataIT(r);
    G := SpaceGroupFunIT(r);
    B := d.basis^-1;

    # translate to pcp group
    i := IsomorphismPcpGroup(G);
    H := Image(i);

    # add normalizer
    N := NormalizerPointGroupInGLnZ(G!.PointGroup);
    if IsFinite(N) then
        n := SmallGeneratingSet(N);
    else
        n := Set(GeneratorsOfGroup(N));
    fi;
    n := List(n, x -> x^B);
    M := Group(n);
    SetSize(M, Size(N));

    # add point group
    P := G!.PointGroup;
    P := List(GeneratorsOfGroup(P), x -> x^B);

    # add info
    H!.norm := M;
    H!.pint := Group(P, IdentityMat(dim));
    H!.iso := i;
    return H;
end;

CrystGroupAsPcpGroupGroup := function( G )
    local r, d, B, i, H, N, n, M, P;

    # extract info
    d := G!.InternalBasis;
    B := d^-1;

    # translate to pcp group
    i := IsomorphismPcpGroup(G);
    H := Image(i);

    # add normalizer
    N := NormalizerPointGroupInGLnZ(G!.PointGroup);
    if IsFinite(N) then
        n := SmallGeneratingSet(N);
    else
        n := Set(GeneratorsOfGroup(N));
    fi;
    n := List(n, x -> x^B);
    M := Group(n);
    SetSize(M, Size(N));

    # add point group
    P := G!.PointGroup;
    P := List(GeneratorsOfGroup(P), x -> x^B);

    # add info
    H!.norm := M;
    H!.pint := Group(P, One(G!.PointGroup));
    H!.iso := i;
    return H;
end;


##
## add various infos to G
##
AddExtensionInfoCG := function(G)
    local T, t, f, F, m, C;

    # check
    if IsBound(G!.crrec) then return; fi;

    # extract translation subgroup
    T := FittingSubgroup(G);
    t := Pcp(T);

    # extract point group
    f := Pcp(G,T);
    F := PcpGroupByPcp(f);

    # get action of F on T and one-cocycles
    m := LinearActionOnPcp(f,t);
    C := rec( factor := Pcp(F),
              mats := m,
              dim := Length(t),
              one := IdentityMat(Length(t)),
              char := 0 );
    AddRelatorsCR(C);
    AddInversesCR(C);

    # add info and store
    C.f := f;
    C.t := t;
    C.h := Concatenation(f!.gens, t!.gens);
    G!.crrec := C;
end;

##
## eventually add a method to compute this normalizer via carat?
##
NormalizerOfPointGroup := function(G)
    if IsBound(G!.norm) then return G!.norm; fi;
    return fail;
end;

